@@ -13,10 +13,6 @@ use Tie::IxHash;
 use Params::Validate qw( :all );
 Params::Validate::validation_options( on_fail => sub { Alzabo::Exception::Params->throw( error => join '', @_ ) } );
 
-use vars qw($VERSION);
-
-$VERSION = 2.0;
-
 #
 # Each pair represents a range of versions which are compatible with
 # each other.  The first one is not quite right but it has to start
@@ -27,12 +23,9 @@ $VERSION = 2.0;
 # version pair.
 #
 my @compat = ( [ 0, 0.64 ],
-	       [ 0.65, 0.70,
+	       [ 0.65, $Alzabo::VERSION,
 		 \&add_comment_fields,
 	       ],
-               [ 0.71, $Alzabo::VERSION,
-                 \&convert_pk_to_array,
-               ],
 	     );
 
 sub update_schema
@@ -119,21 +112,16 @@ EOF
     my $fh = do { local *FH; *FH };
     open $fh, "<$c_file"
 	or Alzabo::Exception::System->throw( error => "Unable to open $c_file: $!" );
-    my $raw = Storable::fd_retrieve($fh)
-        or Alzabo::Exception::System->throw( error => "Can't read filehandle" );
+    my $raw = Storable::retrieve_fd($fh);
     close $fh
 	or Alzabo::Exception::System->throw( error => "Unable to close $c_file: $!" );
 
-    foreach (@cb)
-    {
-        $_->($raw);
-        $_->( $raw->{original} ) if $raw->{original};
-    }
+    $_->($raw) foreach @cb;
 
     open $fh, ">$c_file"
 	or Alzabo::Exception::System->throw( error => "Unable to write to $c_file: $!" );
     Storable::nstore_fd( $raw, $fh )
-	or Alzabo::Exception::System->throw( error => "Can't store to filehandle" );
+	    or Alzabo::Exception::System->throw( error => "Can't store to filehandle" );
     close $fh
 	or Alzabo::Exception::System->throw( error => "Unable to close $c_file: $!" );
 
@@ -181,19 +169,6 @@ sub add_comment_fields
     }
 }
 
-sub convert_pk_to_array
-{
-    my $s = shift;
-
-    foreach my $table ( $s->tables )
-    {
-        my @names = map { $_->name } $table->{pk}->Values;
-        my $pk = [ $table->{columns}->Indices(@names) ];
-
-        $table->{pk} = $pk;
-    }
-}
-
 __END__
 
 =head1 NAME
@@ -205,7 +180,7 @@ Alzabo::BackCompat - Convert old data structures
 This module is used to magically convert schemas with an older data
 structure to the latest format.
 
-More details on how this works can be found in L<Backwards
-Compatibility|Alzabo/Backwards Compatibility>.
+More details on how this works can be found in L<the Backwards
+Compatibility section|Alzabo/Backwards Compatibility>.
 
 =cut
